function creatplot(Parent1, X1, YMatrix1)
%CREATEAXES(Parent1, X1, YMatrix1)
%  PARENT1:  axes parent
%  X1:  vector of plot x data
%  YMATRIX1:  matrix of plot y data
%  Auto-generated by MATLAB on 09-Oct-2023 11:27:41
% Create axes
axes1 = axes('Parent',Parent1);
hold(axes1,'on');
%figure; hold on;
% Create multiple line objects using matrix input to plot
plot1 = plot(X1,YMatrix1,'LineWidth',2,'Parent',axes1);
%plot1 = plot(X1,YMatrix1,'LineWidth',2);
set(plot1(1),'MarkerSize',7,'Marker','+');
set(plot1(2),'Marker','o','LineStyle','-.');
set(plot1(3),'MarkerSize',7,'Marker','^','LineStyle','-.');
set(plot1(4),'MarkerSize',24,'Marker','.');
set(plot1(5),'MarkerSize',8,'Marker','x','LineWidth',3,'LineStyle',':',...
    'Color',[0 1 0]);
set(plot1(6),'MarkerSize',8,'Marker','square','LineStyle','--');
set(plot1(7),'Marker','diamond',...
    'Color',[1 0.411764705882353 0.16078431372549]);
box(axes1,'on');  
hold(axes1,'off');
% Set the remaining axes properties
%set(axes1,'ContextMenu','FontName','Helvetica Neue','FontSize',12,..,'FontWeight','bold');
set(gca,'FontWeight','bold','FontSize',12);